@@ -60,7 +60,7 @@ C KS: added next line
      1   TCRIT, TDIST, TNEXT, TOL, TOLSF, TP, SIZE, SUM, W0
       DIMENSION MORD(2)
       LOGICAL IHIT
-      CHARACTER*80 MSG
+      CHARACTER(LEN=80) MSG
       SAVE MORD, MXSTP0, MXHNL0
 C-----------------------------------------------------------------------
 C The following internal Common block contains
@@ -217,7 +217,8 @@ C If ISTATE = 3, set flag to signal parameter changes to DSTODE. -------
       IF (NQ .LE. MAXORD) GO TO 90
 C MAXORD was reduced below NQ.  Copy YH(*,MAXORD+2) into SAVF. ---------
       DO 80 I = 1,N
- 80     RWORK(I+LSAVF-1) = RWORK(I+LWM-1)
+        RWORK(I+LSAVF-1) = RWORK(I+LWM-1)
+ 80   CONTINUE
 C Reload WM(1) = RWORK(LWM), since LWM may have changed. ---------------
  90   IF (MITER .GT. 0) RWORK(LWM) = SQRT(UROUND)
       IF (N .EQ. NYH) GO TO 200
@@ -226,7 +227,8 @@ C NEQ was reduced.  Zero part of YH to avoid undefined references. -----
       I2 = LYH + (MAXORD + 1)*NYH - 1
       IF (I1 .GT. I2) GO TO 200
       DO 95 I = I1,I2
- 95     RWORK(I) = 0.0D0
+        RWORK(I) = 0.0D0
+ 95   CONTINUE
       GO TO 200
 C-----------------------------------------------------------------------
 C Block C.
@@ -260,14 +262,16 @@ C Initial call to F.  (LF0 points to YH(*,2).) -------------------------
       NFE = 1
 C Load the initial value vector in YH. ---------------------------------
       DO 115 I = 1,N
- 115    RWORK(I+LYH-1) = Y(I)
+        RWORK(I+LYH-1) = Y(I)
+ 115  CONTINUE
 C Load and invert the EWT array.  (H is temporarily set to 1.0.) -------
       NQ = 1
       H = 1.0D0
       CALL DEWSET (N, ITOL, RTOL, ATOL, RWORK(LYH), RWORK(LEWT))
       DO 120 I = 1,N
         IF (RWORK(I+LEWT-1) .LE. 0.0D0) GO TO 621
- 120    RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+        RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+ 120  CONTINUE
 C-----------------------------------------------------------------------
 C The coding below computes the step size, H0, to be attempted on the
 C first step, unless the user has supplied a value for this.
@@ -291,7 +295,8 @@ C-----------------------------------------------------------------------
       TOL = RTOL(1)
       IF (ITOL .LE. 2) GO TO 140
       DO 130 I = 1,N
- 130    TOL = MAX(TOL,RTOL(I))
+        TOL = MAX(TOL,RTOL(I))
+ 130  CONTINUE
  140  IF (TOL .GT. 0.0D0) GO TO 160
       ATOLI = ATOL(1)
       DO 150 I = 1,N
@@ -312,7 +317,8 @@ C Adjust H0 if necessary to meet HMAX bound. ---------------------------
 C Load H with H0 and scale YH(*,2) by H0. ------------------------------
       H = H0
       DO 190 I = 1,N
- 190    RWORK(I+LF0-1) = H0*RWORK(I+LF0-1)
+        RWORK(I+LF0-1) = H0*RWORK(I+LF0-1)
+ 190  CONTINUE
 CKS: start changes      GO TO 270
 C
 C Check for a zero of g at T. ------------------------------------------
@@ -349,7 +355,18 @@ C karline: added from here
       IRFND = 0
       IF (IRFP .EQ. 1 .AND. TLAST .NE. TN .AND. ITASK .EQ. 2) GO TO 400
 C karline: till here
-      GO TO (210, 250, 220, 230, 240), ITASK
+      IF (ITASK .EQ. 1) THEN
+        GOTO 210
+      ELSE IF (ITASK .EQ. 2) THEN
+        GOTO 250
+      ELSE IF (ITASK .EQ. 3) THEN
+        GOTO 220
+      ELSE IF (ITASK .EQ. 4) THEN
+        GOTO 230
+      ELSE IF (ITASK .EQ. 5) THEN
+        GOTO 240
+      ENDIF
+C      GO TO (210, 250, 220, 230, 240), ITASK
  210  IF ((TN - TOUT)*H .LT. 0.0D0) GO TO 250
       CALL DINTDY (TOUT, 0, RWORK(LYH), NYH, Y, IFLAG)
       IF (IFLAG .NE. 0) GO TO 627
@@ -394,7 +411,8 @@ C-----------------------------------------------------------------------
       CALL DEWSET (N, ITOL, RTOL, ATOL, RWORK(LYH), RWORK(LEWT))
       DO 260 I = 1,N
         IF (RWORK(I+LEWT-1) .LE. 0.0D0) GO TO 510
- 260    RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+        RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+ 260    CONTINUE
  270  TOLSF = UROUND*DVNORM (N, RWORK(LYH), RWORK(LEWT))
       IF (TOLSF .LE. 1.0D0) GO TO 280
       TOLSF = TOLSF*2.0D0
@@ -422,7 +440,15 @@ C-----------------------------------------------------------------------
      1   RWORK(LSAVF), RWORK(LACOR), RWORK(LWM), IWORK(LIWM),
      2   F, JAC, DPREPJ, DSOLSY, rpar,ipar)
       KGO = 1 - KFLAG
-      GO TO (300, 530, 540), KGO
+      IF (KGO .EQ. 1) THEN
+        GOTO 300
+      ELSE IF (KGO .EQ. 2) THEN
+        GOTO 530
+      ELSE IF (KGO .EQ. 3) THEN
+        GOTO 540
+      ENDIF
+      
+C      GO TO (300, 530, 540), KGO
 C-----------------------------------------------------------------------
 C Block F.
 C The following block handles the case of a successful return from the
@@ -442,7 +468,18 @@ Ckarline: changed this
       GO TO 425
  315  CONTINUE
 C karline: end of changes
-      GO TO (320, 400, 330, 340, 350), ITASK
+      IF (ITASK .EQ. 1) THEN
+        GOTO 320
+      ELSE IF (ITASK .EQ. 2) THEN
+        GOTO 400
+      ELSE IF (ITASK .EQ. 3) THEN
+        GOTO 330
+      ELSE IF (ITASK .EQ. 4) THEN
+        GOTO 340
+      ELSE IF (ITASK .EQ. 5) THEN
+        GOTO 350
+      ENDIF
+C      GO TO (320, 400, 330, 340, 350), ITASK
 C ITASK = 1.  If TOUT has been reached, interpolate. -------------------
  320  IF ((TN - TOUT)*H .LT. 0.0D0) GO TO 250
       CALL DINTDY (TOUT, 0, RWORK(LYH), NYH, Y, IFLAG)
@@ -475,7 +512,8 @@ C ISTATE is set to 2, and the optional outputs are loaded into the
 C work arrays before returning.
 C-----------------------------------------------------------------------
  400  DO 410 I = 1,N
- 410    Y(I) = RWORK(I+LYH-1)
+        Y(I) = RWORK(I+LYH-1)
+ 410  CONTINUE
       T = TN
       IF (ITASK .NE. 4 .AND. ITASK .NE. 5) GO TO 420
       IF (IHIT) T = TCRIT
@@ -549,7 +587,8 @@ C Compute IMXER if relevant. -------------------------------------------
       IWORK(16) = IMXER
 C Set Y vector, T, and optional outputs. -------------------------------
  580  DO 590 I = 1,N
- 590    Y(I) = RWORK(I+LYH-1)
+        Y(I) = RWORK(I+LYH-1)
+ 590  CONTINUE
       T = TN
       RWORK(11) = HU
       RWORK(12) = H
@@ -752,7 +791,7 @@ C KS: added next lines
      1   TCRIT, TDIST, TNEXT, TOL, TOLSF, TP, SIZE, SUM, W0
       DIMENSION MORD(2)
       LOGICAL IHIT
-      CHARACTER*60 MSG
+      CHARACTER(LEN=60) MSG
       SAVE LENRAT, MORD, MXSTP0, MXHNL0
 C-----------------------------------------------------------------------
 C The following two internal Common blocks contain
@@ -974,13 +1013,15 @@ C Move YH.  Move right if LYHD < 0; move left if LYHD > 0. -------------
       IF (LYHD .LT. 0) THEN
         DO 72 I = LYHN,IMAX
           J = IMAX + LYHN - I
- 72       RWORK(J) = RWORK(J+LYHD)
+          RWORK(J) = RWORK(J+LYHD)
+ 72     CONTINUE
       ENDIF
       IF (LYHD .GT. 0) THEN
         DO 76 I = LYHN,IMAX
- 76       RWORK(I) = RWORK(I+LYHD)
+          RWORK(I) = RWORK(I+LYHD)
+ 76     CONTINUE
       ENDIF
- 80   LYH = LYHN
+      LYH = LYHN
       IWORK(22) = LYH
       IF (MITER .EQ. 0 .OR. MITER .EQ. 3) GO TO 92
       IF (MOSS .NE. 2) GO TO 85
@@ -988,7 +1029,8 @@ C Temporarily load EWT if MITER = 1 or 2 and MOSS = 2. -----------------
       CALL DEWSET (N, ITOL, RTOL, ATOL, RWORK(LYH), RWORK(LEWT))
       DO 82 I = 1,N
         IF (RWORK(I+LEWT-1) .LE. 0.0D0) GO TO 621
- 82     RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+        RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+ 82   CONTINUE
  85   CONTINUE
 C DIPREP and DPREP do sparse matrix preprocessing if MITER = 1 or 2. ---
       LSAVF = MIN(LSAVF,LRW)
@@ -1002,7 +1044,24 @@ CKS
       IF (IPFLAG .NE. -1) IWORK(23) = IPIAN
       IF (IPFLAG .NE. -1) IWORK(24) = IPJAN
       IPGO = -IPFLAG + 1
-      GO TO (90, 628, 629, 630, 631, 632, 633), IPGO
+
+      IF (IPGO .EQ. 1) THEN
+        GOTO 90 
+      ELSE IF (IPGO .EQ. 2) THEN
+        GOTO 628
+      ELSE IF (IPGO .EQ. 3) THEN
+        GOTO 629
+      ELSE IF (IPGO .EQ. 4) THEN
+        GOTO 630
+      ELSE IF (IPGO .EQ. 5) THEN
+        GOTO 631
+      ELSE IF (IPGO .EQ. 6) THEN
+        GOTO 632
+      ELSE IF (IPGO .EQ. 7) THEN
+        GOTO 633
+      ENDIF           
+C      GO TO (90, 628, 629, 630, 631, 632, 633), IPGO
+      
  90   IWORK(22) = LYH
       IF (LENRW .GT. LRW) GO TO 617
 C Set flag to signal parameter changes to DSTODE. ----------------------
@@ -1013,7 +1072,8 @@ C NEQ was reduced.  Zero part of YH to avoid undefined references. -----
       I2 = LYH + (MAXORD + 1)*NYH - 1
       IF (I1 .GT. I2) GO TO 200
       DO 95 I = I1,I2
- 95     RWORK(I) = 0.0D0
+        RWORK(I) = 0.0D0
+ 95   CONTINUE
       GO TO 200
 C-----------------------------------------------------------------------
 C Block C.
@@ -1035,7 +1095,8 @@ C-----------------------------------------------------------------------
       NZU = 0
 C Load the initial value vector in YH. ---------------------------------
       DO 105 I = 1,N
- 105    RWORK(I+LYH-1) = Y(I)
+        RWORK(I+LYH-1) = Y(I)
+ 105  CONTINUE
 C Initial call to F.  (LF0 points to YH(*,2).) -------------------------
       LF0 = LYH + NYH
       CALL F (NEQ, T, Y, RWORK(LF0), rpar, ipar)
@@ -1044,7 +1105,8 @@ C Load and invert the EWT array.  (H is temporarily set to 1.0.) -------
       CALL DEWSET (N, ITOL, RTOL, ATOL, RWORK(LYH), RWORK(LEWT))
       DO 110 I = 1,N
         IF (RWORK(I+LEWT-1) .LE. 0.0D0) GO TO 621
- 110    RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+        RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+ 110  CONTINUE
       IF (MITER .EQ. 0 .OR. MITER .EQ. 3) GO TO 120
 C DIPREP and DPREP do sparse matrix preprocessing if MITER = 1 or 2. ---
       LACOR = MIN(LACOR,LRW)
@@ -1055,7 +1117,22 @@ C DIPREP and DPREP do sparse matrix preprocessing if MITER = 1 or 2. ---
       IF (IPFLAG .NE. -1) IWORK(23) = IPIAN
       IF (IPFLAG .NE. -1) IWORK(24) = IPJAN
       IPGO = -IPFLAG + 1
-      GO TO (115, 628, 629, 630, 631, 632, 633), IPGO
+      IF (IPGO .EQ. 1) THEN
+        GOTO 115
+      ELSE IF (IPGO .EQ. 2) THEN
+        GOTO 628
+      ELSE IF (IPGO .EQ. 3) THEN
+        GOTO 629
+      ELSE IF (IPGO .EQ. 4) THEN
+        GOTO 630
+      ELSE IF (IPGO .EQ. 5) THEN
+        GOTO 631
+      ELSE IF (IPGO .EQ. 6) THEN
+        GOTO 632
+      ELSE IF (IPGO .EQ. 7) THEN
+        GOTO 633
+      ENDIF
+C      GO TO (115, 628, 629, 630, 631, 632, 633), IPGO
  115  IWORK(22) = LYH
       IF (LENRW .GT. LRW) GO TO 617
 C Check TCRIT for legality (ITASK = 4 or 5). ---------------------------
@@ -1109,7 +1186,8 @@ C-----------------------------------------------------------------------
       TOL = RTOL(1)
       IF (ITOL .LE. 2) GO TO 140
       DO 130 I = 1,N
- 130    TOL = MAX(TOL,RTOL(I))
+        TOL = MAX(TOL,RTOL(I))
+ 130  CONTINUE
  140  IF (TOL .GT. 0.0D0) GO TO 160
       ATOLI = ATOL(1)
       DO 150 I = 1,N
@@ -1130,7 +1208,8 @@ C Adjust H0 if necessary to meet HMAX bound. ---------------------------
 C Load H with H0 and scale YH(*,2) by H0. ------------------------------
       H = H0
       DO 190 I = 1,N
- 190    RWORK(I+LF0-1) = H0*RWORK(I+LF0-1)
+        RWORK(I+LF0-1) = H0*RWORK(I+LF0-1)
+ 190  CONTINUE
 CKS: start changes      GO TO 270
 C
 C Check for a zero of g at T. ------------------------------------------
@@ -1167,7 +1246,19 @@ C karline: added from here
       IRFND = 0
       IF (IRFP .EQ. 1 .AND. TLAST .NE. TN .AND. ITASK .EQ. 2) GO TO 400
 C karline: till here
-      GO TO (210, 250, 220, 230, 240), ITASK
+      IF (ITASK .EQ. 1) THEN
+        GOTO 210
+      ELSE IF (ITASK .EQ. 2) THEN
+        GOTO 250
+      ELSE IF (ITASK .EQ. 3) THEN
+        GOTO 220
+      ELSE IF (ITASK .EQ. 4) THEN
+        GOTO 230
+      ELSE IF (ITASK .EQ. 5) THEN
+        GOTO 240
+      ENDIF
+
+C      GO TO (210, 250, 220, 230, 240), ITASK
  210  IF ((TN - TOUT)*H .LT. 0.0D0) GO TO 250
       CALL DINTDY (TOUT, 0, RWORK(LYH), NYH, Y, IFLAG)
       IF (IFLAG .NE. 0) GO TO 627
@@ -1212,7 +1303,8 @@ C-----------------------------------------------------------------------
       CALL DEWSET (N, ITOL, RTOL, ATOL, RWORK(LYH), RWORK(LEWT))
       DO 260 I = 1,N
         IF (RWORK(I+LEWT-1) .LE. 0.0D0) GO TO 510
- 260    RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+        RWORK(I+LEWT-1) = 1.0D0/RWORK(I+LEWT-1)
+ 260  CONTINUE
  270  TOLSF = UROUND*DVNORM (N, RWORK(LYH), RWORK(LEWT))
       IF (TOLSF .LE. 1.0D0) GO TO 280
       TOLSF = TOLSF*2.0D0
@@ -1240,7 +1332,16 @@ C-----------------------------------------------------------------------
      1   RWORK(LSAVF), RWORK(LACOR), RWORK(LWM), RWORK(LWM),
      2   F, JAC, DPRJS, DSOLSS, rpar,ipar)
       KGO = 1 - KFLAG
-      GO TO (300, 530, 540, 550), KGO
+      IF (KGO .EQ. 1) THEN
+        GOTO 300
+      ELSE IF (KGO .EQ. 2) THEN
+        GOTO 530
+      ELSE IF (KGO .EQ. 3) THEN
+        GOTO 540
+      ELSE IF (KGO .EQ. 4) THEN
+        GOTO 550
+      ENDIF
+C      GO TO (300, 530, 540, 550), KGO
 C-----------------------------------------------------------------------
 C Block F.
 C The following block handles the case of a successful return from the
@@ -1259,7 +1360,19 @@ Ckarline: changed this
       T = T0
       GO TO 425
  305  CONTINUE
-      GO TO (310, 400, 330, 340, 350), ITASK
+      IF (ITASK .EQ. 1) THEN
+        GOTO 310
+      ELSE IF (ITASK .EQ. 2) THEN
+        GOTO 400
+      ELSE IF (ITASK .EQ. 3) THEN
+        GOTO 330
+      ELSE IF (ITASK .EQ. 4) THEN
+        GOTO 340
+      ELSE IF (ITASK .EQ. 5) THEN
+        GOTO 350
+      ENDIF
+C GO TO (310, 400, 330, 340, 350), ITASK
+      
 C ITASK = 1.  if TOUT has been reached, interpolate. -------------------
  310  IF ((TN - TOUT)*H .LT. 0.0D0) GO TO 250
       CALL DINTDY (TOUT, 0, RWORK(LYH), NYH, Y, IFLAG)
@@ -1292,7 +1405,8 @@ C ISTATE is set to 2, and the optional outputs are loaded into the
 C work arrays before returning.
 C-----------------------------------------------------------------------
  400  DO 410 I = 1,N
- 410    Y(I) = RWORK(I+LYH-1)
+        Y(I) = RWORK(I+LYH-1)
+ 410  CONTINUE
       T = TN
       IF (ITASK .NE. 4 .AND. ITASK .NE. 5) GO TO 420
       IF (IHIT) T = TCRIT
@@ -1381,7 +1495,8 @@ C Compute IMXER if relevant. -------------------------------------------
       IWORK(16) = IMXER
 C Set Y vector, T, and optional outputs. -------------------------------
  580  DO 590 I = 1,N
- 590    Y(I) = RWORK(I+LYH-1)
+        Y(I) = RWORK(I+LYH-1)
+ 590  CONTINUE
       T = TN
       RWORK(11) = HU
       RWORK(12) = H
